@@ -11,9 +11,11 @@ import skyview.util.SetTimeout;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Set;
-import java.util.regex.*;
+import java.io.StringWriter;
+import java.io.PrintWriter;
 import skyview.request.Detainter;
 import skyview.request.SkyViewDetainter;
+import org.apache.commons.lang3.StringEscapeUtils;
 
 /**
  * This class initiates a SkyView request from CGI.
@@ -280,7 +282,8 @@ public class CGIInitiator {
          System.out.println("<h2> Exception encountered</h2>\n");
          System.out.println("An irrecoverable error terminated the "
                  + "request.<p>");
-         System.out.println("Reason: " + e.getMessage() + "<p>");
+         String escapedMessage = StringEscapeUtils.escapeHtml4(e.getMessage()).replace("'", "&#39;");
+         System.out.println("Reason: " + escapedMessage + "<p>");
          System.out.println("Please refer to the "
                  + "<a href='/help/fields.html'>SkyView documentation</a> or "
                  + "<a href='https://heasarc.gsfc.nasa.gov/cgi-bin/Feedback?"
@@ -292,8 +295,12 @@ public class CGIInitiator {
                  + "style.visibility=\"visible\"' value='Show Traceback'>");
          System.out.println("<div id=traceback style='visibility:hidden'>"
                  + "<pre>");
-         System.out.println("Java Traceback<br>");
-         e.printStackTrace(System.out);
+         System.out.println("Java Stacktrace:\n");
+         StringWriter sw = new StringWriter();
+         PrintWriter pw = new PrintWriter(sw);
+         e.printStackTrace(pw);
+         String stacktrace = sw.getBuffer().toString();
+         System.out.println(StringEscapeUtils.escapeHtml4(stacktrace).replace("'", "&#39;"));
          System.out.println("</pre></div></body></html>");
       } finally {
          System.exit(0);
